@@ -43,14 +43,32 @@
 #' @export
 #' @example examples/fn_case.R
 
-fn_case <- function(x, fn, ..., preserve = FALSE, default = NA) {
-  dots <- allow_dot_aliases(compact_list(...))
+fn_case <- function(
+  x,
+  fn,
+  ...,
+  .preserve = FALSE,
+  .default = NA,
+  .exhaustive = FALSE,
+  preserve = deprecated(),
+  default = deprecated()
+) {
+  .preserve <- coalesce_deprecated(.preserve, preserve)
+  .default <- coalesce_deprecated(.default, default)
+
+  dots <- compact_list(...)
   inputs <- fn_case_setup(dots)
 
   replace(
-    inputs$fs, x, default, preserve, fn, inputs$args,
-    default_env = rlang::caller_env(),
-    current_env = rlang::current_env()
+    fs = inputs$fs,
+    x = x,
+    .default = .default,
+    .preserve = .preserve,
+    .exhaustive = .exhaustive,
+    fn = fn,
+    args = inputs$args,
+    default_env = first_incase_frame_parent(),
+    current_env = first_incase_frame()
   )
 }
 
