@@ -32,12 +32,33 @@
 #'
 #' @example examples/grep_case.R
 
-grep_case <- function(x, ..., preserve = FALSE, default = NA) {
+grep_case <- function(
+  x,
+  ...,
+  .preserve = FALSE,
+  .default = NA,
+  .exhaustive = FALSE,
+  preserve = deprecated(),
+  default = deprecated()
+) {
   fn_case(
-    x  = x,
-    fn = function(x, pattern, ...) grepl(pattern, x, ...),
+    x = x,
+    fn = grepl_any,
     ...,
+    .preserve = .preserve,
+    .default = .default,
+    .exhaustive = .exhaustive,
     preserve = preserve,
-    default  = default
+    default = default
   )
 }
+
+grepl_any <- function(x, pattern, ...) {
+  logical <- vapply(pattern, grepl, logical(length(x)), x, ...)
+  logical <- matrix(logical, nrow = length(x))
+  apply(logical, 1, or_reduce)
+}
+
+or_reduce <- function(logical) {
+  Reduce(`|`, logical)
+}
