@@ -16,16 +16,28 @@
 #'   For `switch_case()`, named arguments will raise an error.
 #'
 #' @param fn A function to apply to the left-hand side of each formula in `...`
-#' @param preserve If `TRUE`, unmatched elements of `x` will be returned
+#' @param .preserve If `TRUE`, unmatched elements of `x` will be returned
 #'   unmodified.
 #'   (The elements may have their type coerced to be compatible with
 #'   replacement values.)
-#'   If `FALSE`, unmatched elements of `x` will be replaced with `default`.
+#'   If `FALSE`, unmatched elements of `x` will be replaced with `.default`.
 #'   Defaults to `FALSE`.
-#' @param default If `preserve` is `FALSE`, a value to replace unmatched
+#' @param .default If `.preserve` is `FALSE`, a value to replace unmatched
 #'   elements of `x`.
 #'   Defaults to `NA`.
 #'
+#' @param .exhaustive If `TRUE`, unmatched elements of `x` will result in
+#'   an error.
+#'   This can be useful to ensure you aren't accidentally forgetting to recode
+#'   any values.
+#'   Defaults to `FALSE`.
+#'
+#'   Note that if `.preserve` is `TRUE`,
+#'   `.exhaustive` will never have any effect.
+#'
+#' @param preserve,default `r lifecycle::badge("deprecated")`
+#'   Deprecated in favor of `.preserve` and `.default`
+#'
 #' @return A vector of the same length as `x`.
 #'
 #' @seealso [switch_case_fct()] and [fn_switch_case_fct()] to return a factor
@@ -43,40 +55,76 @@
 #'
 #' @example examples/switch_case.R
 
-switch_case <- function(x, ..., preserve = FALSE, default = NA) {
+switch_case <- function(
+  x,
+  ...,
+  .preserve = FALSE,
+  .default = NA,
+  .exhaustive = FALSE,
+  preserve = deprecated(),
+  default = deprecated()
+) {
   fn_case(
     x  = x,
     fn = `%in%`,
     ...,
+    .preserve = .preserve,
+    .default  = .default,
+    .exhaustive = .exhaustive,
     preserve = preserve,
-    default  = default
+    default = default
   )
 }
 
 #' @rdname switch_case
 #' @export
 
-fn_switch_case <- function(x, fn, ..., preserve = FALSE, default = NA) {
-  inputs <- fn_switch_case_setup(
-    ...,
+fn_switch_case <- function(
+  x,
+  fn,
+  ...,
+  .preserve = FALSE,
+  .default = NA,
+  .exhaustive = FALSE,
+  preserve = deprecated(),
+  default = deprecated()
+) {
+  eval.parent(fn_switch_case_call(switch_case, fn, ...))
+}
+
+fn_switch_case_call <- function(
+  switch_case_fn,
+  fn,
+  ...,
+  call = rlang::caller_call(),
+  current_fn = rlang::caller_fn()
+) {
+  args <- as.list(call)[-1]
+
+  dots <- compact_list(...)
+  dots_idx <- which(args %in% dots)
+
+  dots <- fn_switch_case_setup(
+    dots,
     fn          = fn,
     default_env = rlang::caller_env(),
     current_env = rlang::current_env()
   )
 
-  do.call(
-    switch_case,
-    c(
-      list(x = x), inputs$fs, inputs$args,
-      list(preserve = preserve, default = default)
-    )
-  )
+  args[dots_idx] <- dots
+  args <- args[!vapply(args, rlang::is_missing, logical(1))]
+
+  fn_idx <- which(args == rlang::call_match(call, current_fn)[["fn"]])
+  args <- args[-fn_idx]
+
+  rlang::call2(switch_case_fn, !!!args)
 }
 
-fn_switch_case_setup <- function(..., fn, default_env, current_env) {
-  input <- compact_list(...)
-  fs    <- Filter(rlang::is_formula, input)
-  args  <- input[!input %in% fs]
+fn_switch_case_setup <- function(dots, fn, default_env, current_env) {
+  are_formulas <- vapply(dots, rlang::is_formula, logical(1))
+
+  fs    <- dots[are_formulas]
+  args  <- dots[!are_formulas]
 
   assert_length(fs, call = current_env)
 
@@ -96,5 +144,8 @@ fn_switch_case_setup <- function(..., fn, default_env, current_env) {
     fs, pairs$query, pairs$value
   )
 
-  list(fs = fs, args = args)
+  dots[are_formulas] <- fs
+  dots[!are_formulas] <- list(rlang::missing_arg())
+
+  dots
 }
